Flask-Orator
############

.. image:: https://travis-ci.org/sdispater/flask-orator.png
   :alt: Orator Build status
   :target: https://travis-ci.org/sdispater/flask-orator

Flask-Orator adds `Orator ORM <https://github.com/sdispater/orator>`_ support to Flask applications.


Resources
=========

You can install Orator in 2 different ways:

* `Documentation <http://flask-orator.readthedocs.org>`_
* `Issue Tracker <https://github.com/sdispater/flask-orator/issues>`_
